/*****************
 * Configuration *
 *****************/

/* MEGACO MG Configuration */ 
#define MEGACO_MAX_MSG_SIZE    1024
#define PROTOCOL               "MEGACO/1"
#define PROFILE                "IPPhone/1"

/* RTP MG Configuration */
#define RTP_MAX_MSG_SIZE       100
#define RTP_PORT               "2222"


/*******************
 * Type definition *
 *******************/
#define FALSE 0
#define TRUE  1


/*****************************
 * MEGACO (H.248) definition *
 *****************************/

/* ServiceChange Descriptor */
const char *ServiceChangeMethodString[] = 
{
  "Failover", 
  "Forced", 
  "Graceful", 
  "Restart", 
  "Disconnected", 
  "Handoff",
  "MEGACO_END"
};

typedef enum
{
  MEGACO_FailoverMethodKey,
  MEGACO_ForcedMethodKey,
  MEGACO_GracefulMethodKey,
  MEGACO_RestartMethodKey,
  MEGACO_DisconnectedMethodKey,
  MEGACO_HandoffMethodKey,
  MEGACO_NumMethodKey
} MEGACO_ServiceChangeMethodKeyType;

typedef struct
{
  int  ServiceChangeMethodKey;
  int  ServiceChangeAddressNum;
  char ServiceChangeProfile[64];
} MEGACO_ServiceChangeDescType;


/* LocalControl Descriptor */
const char *StreamModeString[] =
{
  "SendOnly",
  "ReceiveOnly",
  "SendReceive",
  "Inactive",
  "LoopBack",
  "MEGACO_END"
}; 

typedef enum
{
  MEGACO_SendOnlyModeKey,
  MEGACO_RecvOnlyModeKey,
  MEGACO_SendRecvModeKey,
  MEGACO_InactiveModeKey,
  MEGACO_LoopBackModeKey,
  MEGACO_NumModeKey
} MEGACO_StreamModeKeyType;

typedef struct
{
  int StreamModeKey;	
} MEGACO_LocalControlDescType;

/* Local Descriptor */
typedef struct
{
  char LocalC[64];
  char LocalM[64];
  char LocalIPAddress[16];
  int  LocalIPPortNum;
} MEGACO_LocalDescType;

/* Remote Descriptor */
typedef struct
{
  char RemoteC[64];
  char RemoteM[64];
  char RemoteIPAddress[16];
  int  RemoteIPPortNum;
} MEGACO_RemoteDescType;

/* Media Descriptor */
typedef struct
{
  MEGACO_LocalControlDescType LocalControlDesc;;
  MEGACO_LocalDescType        LocalDesc;	
  MEGACO_RemoteDescType       RemoteDesc;	
} MEGACO_MediaDescType;


/* Events Descriptor */
const char *EventTypeString[] =
{
  "key/kd",
  "key/ku",
  "key/kf",
  "dd/ce",
  "MEGACO_END"
}; 

typedef enum
{
  MEGACO_KeyKdEvent,
  MEGACO_KeyKuEvent,
  MEGACO_KeyFlashEvent,
  MEGACO_KeyDigitEvent,
  MEGACO_NumEvent
} MEGACO_EventType;

typedef struct
{
  int EventTypeRequestIdNum[MEGACO_NumEvent];
} MEGACO_EventDescType;

/* Signals Descriptor */
const char *SignalTypeString[] = 
{
  "ERROR",
  "cg/dt",
  "cg/rt"	   
};

typedef enum 
{
  MEGACO_CgDt=1, 
  MEGACO_CgRt,
  MEGACO_NumSignal
} MEGACO_SignalType;

typedef struct
{
  int SignalTypeRequestIdNum[MEGACO_NumSignal];
} MEGACO_SignalDescType;


/* Statistics Descriptor */
typedef struct
{
  int PktSentNum;
  int ByteSentNum;
  int PktRecvNum;
  int ByteRecvNum;
  int PktLossNum; 
  int PktJitterNum;
  int PktDelayNum;
} MEGACO_StatisticsDescType;

/***********************
 * MG Node Definition *
 **********************/
typedef enum 
{
  MG_RestartState,
  MG_RegisteringState,
  MG_RegisterState,
  MG_ConnectState,
  MG_HoldState,
  MG_EndState
} MG_StatusType;

typedef enum 
{
  MG_ServiceChangeCommand, 
  MG_ModifyCommand, 
  MG_NotifyCommand, 
  MG_AddCommand, 
  MG_SubtractCommand,
  MG_MoveCommand,
  MG_AuditValueCommand,
  MG_AuditCapabilitiesCommand,
  MG_InvalidCommand
} MG_CommandType;

typedef enum
{
  MG_NoPkt,
  MG_MegacoPkt,
  MG_RtpPkt
} MG_RxPktType;

typedef struct
{
  char                         ContextId[64];
  MEGACO_ServiceChangeDescType ServiceChangeDescriptor;
} MG_RootTermination;

typedef struct 
{
  char                  ContextId[64];
  MEGACO_SignalDescType SignalDescriptor;    
} MG_ATTermination;

typedef struct 
{
  char                 ContextId[64];
  MEGACO_EventDescType EventDescriptor;
} MG_UITermination;

typedef struct 
{
  char                      ContextId[64];
  MEGACO_MediaDescType      MediaDescriptor;
  MEGACO_StatisticsDescType StatisticsDescriptor;
} MG_TRTermination;

typedef struct 
{
  MG_RootTermination RootTermination;
  MG_ATTermination   ATTermination;
  MG_UITermination   UITermination;
  MG_TRTermination   TRTermination;
} MG_InfoType;

typedef struct 
{
  char *msg;
} MG_MegacoMsgType;

typedef struct 
{
  char *msg;
} RTP_MsgType;
